pub enum ITIP20ChannelReserveCalls {
Show 14 variants
CLOSE_GRACE_PERIOD(CLOSE_GRACE_PERIODCall),
VOUCHER_TYPEHASH(VOUCHER_TYPEHASHCall),
open(openCall),
settle(settleCall),
topUp(topUpCall),
close(closeCall),
requestClose(requestCloseCall),
withdraw(withdrawCall),
getChannel(getChannelCall),
getChannelState(getChannelStateCall),
getChannelStatesBatch(getChannelStatesBatchCall),
computeChannelId(computeChannelIdCall),
getVoucherDigest(getVoucherDigestCall),
domainSeparator(domainSeparatorCall),
}Expand description
Container for all the ITIP20ChannelReserve function calls.
Variants
CLOSE_GRACE_PERIOD(CLOSE_GRACE_PERIODCall)
VOUCHER_TYPEHASH(VOUCHER_TYPEHASHCall)
open(openCall)
settle(settleCall)
topUp(topUpCall)
close(closeCall)
requestClose(requestCloseCall)
withdraw(withdrawCall)
getChannel(getChannelCall)
getChannelState(getChannelStateCall)
getChannelStatesBatch(getChannelStatesBatchCall)
computeChannelId(computeChannelIdCall)
getVoucherDigest(getVoucherDigestCall)
domainSeparator(domainSeparatorCall)
Implementations
Sourceimpl ITIP20ChannelReserveCalls
impl ITIP20ChannelReserveCalls
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20ChannelReserveCalls
impl ITIP20ChannelReserveCalls
Sourcepub fn is_payment_with_valid_signature(
input: &[u8],
validate_signature: impl Fn(&[u8]) -> bool,
) -> bool
pub fn is_payment_with_valid_signature( input: &[u8], validate_signature: impl Fn(&[u8]) -> bool, ) -> bool
Returns true if input matches one of the recognized TIP-20 channel reserve payment
selectors: open, topUp, settle, close, requestClose, withdraw.
NOTES
- Only validates calldata; caller must check that
to == TIP20_CHANNEL_RESERVE_ADDRESS. - Static-only calls require exact ABI-encoded length.
- Dynamic calls require valid ABI decoding and calldata length <=
MAX_PAYMENT_CALLDATA_LEN. - Dynamic calls also require valid
signatureencoding.