pub enum ITIP20ChannelReserveErrors {
Show 13 variants
ChannelAlreadyExists(ChannelAlreadyExists),
ChannelNotFound(ChannelNotFound),
NotPayer(NotPayer),
NotPayeeOrOperator(NotPayeeOrOperator),
InvalidPayee(InvalidPayee),
ZeroDeposit(ZeroDeposit),
ExpiringNonceHashNotSet(ExpiringNonceHashNotSet),
InvalidSignature(InvalidSignature),
AmountExceedsDeposit(AmountExceedsDeposit),
AmountNotIncreasing(AmountNotIncreasing),
CaptureAmountInvalid(CaptureAmountInvalid),
CloseNotReady(CloseNotReady),
DepositOverflow(DepositOverflow),
}Expand description
Container for all the ITIP20ChannelReserve custom errors.
Variants
ChannelAlreadyExists(ChannelAlreadyExists)
ChannelNotFound(ChannelNotFound)
NotPayer(NotPayer)
NotPayeeOrOperator(NotPayeeOrOperator)
InvalidPayee(InvalidPayee)
ZeroDeposit(ZeroDeposit)
ExpiringNonceHashNotSet(ExpiringNonceHashNotSet)
InvalidSignature(InvalidSignature)
AmountExceedsDeposit(AmountExceedsDeposit)
AmountNotIncreasing(AmountNotIncreasing)
CaptureAmountInvalid(CaptureAmountInvalid)
CloseNotReady(CloseNotReady)
DepositOverflow(DepositOverflow)
Implementations
Sourceimpl ITIP20ChannelReserveErrors
impl ITIP20ChannelReserveErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20ChannelReserveErrors
impl ITIP20ChannelReserveErrors
Sourcepub fn channel_already_exists() -> Self
pub fn channel_already_exists() -> Self
Creates a ChannelAlreadyExists error.
error ChannelAlreadyExists()Sourcepub fn channel_not_found() -> Self
pub fn channel_not_found() -> Self
Creates a ChannelNotFound error.
error ChannelNotFound()Sourcepub fn not_payee_or_operator() -> Self
pub fn not_payee_or_operator() -> Self
Creates a NotPayeeOrOperator error.
error NotPayeeOrOperator()Sourcepub fn invalid_payee() -> Self
pub fn invalid_payee() -> Self
Creates a InvalidPayee error.
error InvalidPayee()Sourcepub fn zero_deposit() -> Self
pub fn zero_deposit() -> Self
Creates a ZeroDeposit error.
error ZeroDeposit()Sourcepub fn expiring_nonce_hash_not_set() -> Self
pub fn expiring_nonce_hash_not_set() -> Self
Creates a ExpiringNonceHashNotSet error.
error ExpiringNonceHashNotSet()Sourcepub fn invalid_signature() -> Self
pub fn invalid_signature() -> Self
Creates a InvalidSignature error.
error InvalidSignature()Sourcepub fn amount_exceeds_deposit() -> Self
pub fn amount_exceeds_deposit() -> Self
Creates a AmountExceedsDeposit error.
error AmountExceedsDeposit()Sourcepub fn amount_not_increasing() -> Self
pub fn amount_not_increasing() -> Self
Creates a AmountNotIncreasing error.
error AmountNotIncreasing()Sourcepub fn capture_amount_invalid() -> Self
pub fn capture_amount_invalid() -> Self
Creates a CaptureAmountInvalid error.
error CaptureAmountInvalid()Sourcepub fn close_not_ready() -> Self
pub fn close_not_ready() -> Self
Creates a CloseNotReady error.
error CloseNotReady()Sourcepub fn deposit_overflow() -> Self
pub fn deposit_overflow() -> Self
Creates a DepositOverflow error.
error DepositOverflow()Trait Implementations
Sourceimpl Clone for ITIP20ChannelReserveErrors
impl Clone for ITIP20ChannelReserveErrors
Sourcefn clone(&self) -> ITIP20ChannelReserveErrors
fn clone(&self) -> ITIP20ChannelReserveErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ITIP20ChannelReserveErrors
impl Debug for ITIP20ChannelReserveErrors
Sourceimpl<'de> Deserialize<'de> for ITIP20ChannelReserveErrors
impl<'de> Deserialize<'de> for ITIP20ChannelReserveErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP20ChannelReserveErrors
Sourceimpl PartialEq for ITIP20ChannelReserveErrors
impl PartialEq for ITIP20ChannelReserveErrors
Sourcefn eq(&self, other: &ITIP20ChannelReserveErrors) -> bool
fn eq(&self, other: &ITIP20ChannelReserveErrors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl SolInterface for ITIP20ChannelReserveErrors
impl SolInterface for ITIP20ChannelReserveErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for ITIP20ChannelReserveErrors