pub enum ITIP20ChannelReserveEvents {
ChannelOpened(ChannelOpened),
Settled(Settled),
TopUp(TopUp),
CloseRequested(CloseRequested),
ChannelClosed(ChannelClosed),
CloseRequestCancelled(CloseRequestCancelled),
}Expand description
Container for all the ITIP20ChannelReserve events.
Variants
ChannelOpened(ChannelOpened)
Settled(Settled)
TopUp(TopUp)
CloseRequested(CloseRequested)
ChannelClosed(ChannelClosed)
CloseRequestCancelled(CloseRequestCancelled)
Implementations
Sourceimpl ITIP20ChannelReserveEvents
impl ITIP20ChannelReserveEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20ChannelReserveEvents
impl ITIP20ChannelReserveEvents
Sourcepub fn channel_opened(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
operator: Address,
token: Address,
authorized_signer: Address,
salt: FixedBytes<32>,
expiring_nonce_hash: FixedBytes<32>,
deposit: U96,
) -> Self
pub fn channel_opened( channel_id: FixedBytes<32>, payer: Address, payee: Address, operator: Address, token: Address, authorized_signer: Address, salt: FixedBytes<32>, expiring_nonce_hash: FixedBytes<32>, deposit: U96, ) -> Self
Creates a ChannelOpened event.
event ChannelOpened(bytes32,address,address,address,address,address,bytes32,bytes32,uint96)Sourcepub fn settled(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
cumulative_amount: U96,
delta_paid: U96,
new_settled: U96,
) -> Self
pub fn settled( channel_id: FixedBytes<32>, payer: Address, payee: Address, cumulative_amount: U96, delta_paid: U96, new_settled: U96, ) -> Self
Creates a Settled event.
event Settled(bytes32,address,address,uint96,uint96,uint96)Sourcepub fn top_up(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
additional_deposit: U96,
new_deposit: U96,
) -> Self
pub fn top_up( channel_id: FixedBytes<32>, payer: Address, payee: Address, additional_deposit: U96, new_deposit: U96, ) -> Self
Creates a TopUp event.
event TopUp(bytes32,address,address,uint96,uint96)Sourcepub fn close_requested(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
close_grace_end: U256,
) -> Self
pub fn close_requested( channel_id: FixedBytes<32>, payer: Address, payee: Address, close_grace_end: U256, ) -> Self
Creates a CloseRequested event.
event CloseRequested(bytes32,address,address,uint256)Sourcepub fn channel_closed(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
settled_to_payee: U96,
refunded_to_payer: U96,
) -> Self
pub fn channel_closed( channel_id: FixedBytes<32>, payer: Address, payee: Address, settled_to_payee: U96, refunded_to_payer: U96, ) -> Self
Creates a ChannelClosed event.
event ChannelClosed(bytes32,address,address,uint96,uint96)Sourcepub fn close_request_cancelled(
channel_id: FixedBytes<32>,
payer: Address,
payee: Address,
) -> Self
pub fn close_request_cancelled( channel_id: FixedBytes<32>, payer: Address, payee: Address, ) -> Self
Creates a CloseRequestCancelled event.
event CloseRequestCancelled(bytes32,address,address)Trait Implementations
Sourceimpl Clone for ITIP20ChannelReserveEvents
impl Clone for ITIP20ChannelReserveEvents
Sourcefn clone(&self) -> ITIP20ChannelReserveEvents
fn clone(&self) -> ITIP20ChannelReserveEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ITIP20ChannelReserveEvents
impl Debug for ITIP20ChannelReserveEvents
Sourceimpl<'de> Deserialize<'de> for ITIP20ChannelReserveEvents
impl<'de> Deserialize<'de> for ITIP20ChannelReserveEvents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP20ChannelReserveEvents
Sourceimpl IntoLogData for ITIP20ChannelReserveEvents
impl IntoLogData for ITIP20ChannelReserveEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for ITIP20ChannelReserveEvents
impl PartialEq for ITIP20ChannelReserveEvents
Sourcefn eq(&self, other: &ITIP20ChannelReserveEvents) -> bool
fn eq(&self, other: &ITIP20ChannelReserveEvents) -> bool
self and other values to be equal, and is used by ==.Sourceimpl SolEventInterface for ITIP20ChannelReserveEvents
impl SolEventInterface for ITIP20ChannelReserveEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ITIP20ChannelReserveEvents