pub struct ITIP20ChannelReserveInstance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A ITIP20ChannelReserve instance.
Contains type-safe methods for interacting with an on-chain instance of the
ITIP20ChannelReserve contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain ITIP20ChannelReserve contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> ITIP20ChannelReserveInstance<&P, N>
impl<P: Clone, N> ITIP20ChannelReserveInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> ITIP20ChannelReserveInstance<P, N>
pub fn with_cloned_provider(self) -> ITIP20ChannelReserveInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn CLOSE_GRACE_PERIOD(
&self,
) -> SolCallBuilder<&P, CLOSE_GRACE_PERIODCall, N>
pub fn CLOSE_GRACE_PERIOD( &self, ) -> SolCallBuilder<&P, CLOSE_GRACE_PERIODCall, N>
Creates a new call builder for the [CLOSE_GRACE_PERIOD] function.
Sourcepub fn VOUCHER_TYPEHASH(&self) -> SolCallBuilder<&P, VOUCHER_TYPEHASHCall, N>
pub fn VOUCHER_TYPEHASH(&self) -> SolCallBuilder<&P, VOUCHER_TYPEHASHCall, N>
Creates a new call builder for the [VOUCHER_TYPEHASH] function.
Sourcepub fn open(
&self,
payee: Address,
operator: Address,
token: Address,
deposit: U96,
salt: FixedBytes<32>,
authorizedSigner: Address,
) -> SolCallBuilder<&P, openCall, N>
pub fn open( &self, payee: Address, operator: Address, token: Address, deposit: U96, salt: FixedBytes<32>, authorizedSigner: Address, ) -> SolCallBuilder<&P, openCall, N>
Creates a new call builder for the [open] function.
Sourcepub fn settle(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
cumulativeAmount: U96,
signature: Bytes,
) -> SolCallBuilder<&P, settleCall, N>
pub fn settle( &self, descriptor: <ChannelDescriptor as SolType>::RustType, cumulativeAmount: U96, signature: Bytes, ) -> SolCallBuilder<&P, settleCall, N>
Creates a new call builder for the [settle] function.
Sourcepub fn topUp(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
additionalDeposit: U96,
) -> SolCallBuilder<&P, topUpCall, N>
pub fn topUp( &self, descriptor: <ChannelDescriptor as SolType>::RustType, additionalDeposit: U96, ) -> SolCallBuilder<&P, topUpCall, N>
Creates a new call builder for the [topUp] function.
Sourcepub fn close(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
cumulativeAmount: U96,
captureAmount: U96,
signature: Bytes,
) -> SolCallBuilder<&P, closeCall, N>
pub fn close( &self, descriptor: <ChannelDescriptor as SolType>::RustType, cumulativeAmount: U96, captureAmount: U96, signature: Bytes, ) -> SolCallBuilder<&P, closeCall, N>
Creates a new call builder for the [close] function.
Sourcepub fn requestClose(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> SolCallBuilder<&P, requestCloseCall, N>
pub fn requestClose( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> SolCallBuilder<&P, requestCloseCall, N>
Creates a new call builder for the [requestClose] function.
Sourcepub fn withdraw(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> SolCallBuilder<&P, withdrawCall, N>
pub fn withdraw( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> SolCallBuilder<&P, withdrawCall, N>
Creates a new call builder for the [withdraw] function.
Sourcepub fn getChannel(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> SolCallBuilder<&P, getChannelCall, N>
pub fn getChannel( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> SolCallBuilder<&P, getChannelCall, N>
Creates a new call builder for the [getChannel] function.
Sourcepub fn getChannelState(
&self,
channelId: FixedBytes<32>,
) -> SolCallBuilder<&P, getChannelStateCall, N>
pub fn getChannelState( &self, channelId: FixedBytes<32>, ) -> SolCallBuilder<&P, getChannelStateCall, N>
Creates a new call builder for the [getChannelState] function.
Sourcepub fn getChannelStatesBatch(
&self,
channelIds: Vec<FixedBytes<32>>,
) -> SolCallBuilder<&P, getChannelStatesBatchCall, N>
pub fn getChannelStatesBatch( &self, channelIds: Vec<FixedBytes<32>>, ) -> SolCallBuilder<&P, getChannelStatesBatchCall, N>
Creates a new call builder for the [getChannelStatesBatch] function.
Sourcepub fn computeChannelId(
&self,
payer: Address,
payee: Address,
operator: Address,
token: Address,
salt: FixedBytes<32>,
authorizedSigner: Address,
expiringNonceHash: FixedBytes<32>,
) -> SolCallBuilder<&P, computeChannelIdCall, N>
pub fn computeChannelId( &self, payer: Address, payee: Address, operator: Address, token: Address, salt: FixedBytes<32>, authorizedSigner: Address, expiringNonceHash: FixedBytes<32>, ) -> SolCallBuilder<&P, computeChannelIdCall, N>
Creates a new call builder for the [computeChannelId] function.
Sourcepub fn getVoucherDigest(
&self,
channelId: FixedBytes<32>,
cumulativeAmount: U96,
) -> SolCallBuilder<&P, getVoucherDigestCall, N>
pub fn getVoucherDigest( &self, channelId: FixedBytes<32>, cumulativeAmount: U96, ) -> SolCallBuilder<&P, getVoucherDigestCall, N>
Creates a new call builder for the [getVoucherDigest] function.
Sourcepub fn domainSeparator(&self) -> SolCallBuilder<&P, domainSeparatorCall, N>
pub fn domainSeparator(&self) -> SolCallBuilder<&P, domainSeparatorCall, N>
Creates a new call builder for the [domainSeparator] function.
Sourceimpl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> ITIP20ChannelReserveInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn ChannelOpened_filter(&self) -> Event<&P, ChannelOpened, N>
pub fn ChannelOpened_filter(&self) -> Event<&P, ChannelOpened, N>
Creates a new event filter for the ChannelOpened event.
Sourcepub fn Settled_filter(&self) -> Event<&P, Settled, N>
pub fn Settled_filter(&self) -> Event<&P, Settled, N>
Creates a new event filter for the Settled event.
Sourcepub fn TopUp_filter(&self) -> Event<&P, TopUp, N>
pub fn TopUp_filter(&self) -> Event<&P, TopUp, N>
Creates a new event filter for the TopUp event.
Sourcepub fn CloseRequested_filter(&self) -> Event<&P, CloseRequested, N>
pub fn CloseRequested_filter(&self) -> Event<&P, CloseRequested, N>
Creates a new event filter for the CloseRequested event.
Sourcepub fn ChannelClosed_filter(&self) -> Event<&P, ChannelClosed, N>
pub fn ChannelClosed_filter(&self) -> Event<&P, ChannelClosed, N>
Creates a new event filter for the ChannelClosed event.
Sourcepub fn CloseRequestCancelled_filter(
&self,
) -> Event<&P, CloseRequestCancelled, N>
pub fn CloseRequestCancelled_filter( &self, ) -> Event<&P, CloseRequestCancelled, N>
Creates a new event filter for the CloseRequestCancelled event.