pub struct requestCloseCall {
pub descriptor: <ChannelDescriptor as SolType>::RustType,
}Expand description
Starts the payer withdrawal timer.
Function with signature requestClose((address,address,address,address,bytes32,address,bytes32)) and selector 0x675402e5.
function requestClose(ChannelDescriptor calldata descriptor) external;Fields
descriptor: <ChannelDescriptor as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for requestCloseCall
impl Clone for requestCloseCall
Sourcefn clone(&self) -> requestCloseCall
fn clone(&self) -> requestCloseCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for requestCloseCall
impl Debug for requestCloseCall
Sourceimpl<'de> Deserialize<'de> for requestCloseCall
impl<'de> Deserialize<'de> for requestCloseCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requestCloseCall
Sourceimpl JsonAbiExt for requestCloseCall
impl JsonAbiExt for requestCloseCall
Sourceimpl PartialEq for requestCloseCall
impl PartialEq for requestCloseCall
Sourcefn eq(&self, other: &requestCloseCall) -> bool
fn eq(&self, other: &requestCloseCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requestCloseCall
impl Serialize for requestCloseCall
Sourceimpl SolCall for requestCloseCall
impl SolCall for requestCloseCall
Sourceconst SIGNATURE: &'static str = "requestClose((address,address,address,address,bytes32,address,bytes32))"
const SIGNATURE: &'static str = "requestClose((address,address,address,address,bytes32,address,bytes32))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (ChannelDescriptor,)
type Parameters<'a> = (ChannelDescriptor,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<requestCloseCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<requestCloseCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = requestCloseReturn
type Return = requestCloseReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<requestCloseCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<requestCloseCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl StructuralPartialEq for requestCloseCall